@@ -8,7 +8,7 @@ BEGIN {
     our @ISA = qw( ExtUtils::MM_Unix );
 }
 
-our $VERSION = '7.49_03';
+our $VERSION = '7.49_04';
 $VERSION =~ tr/_//d;
 
 
@@ -46,4 +46,18 @@ sub init_dist {
     $self->SUPER::init_dist(@_);
 }
 
+=head3 cflags
+
+Over-ride Apple's automatic setting of -Werror
+
+=cut
+
+sub cflags {
+    my $self = shift;
+
+    $self->{CCFLAGS} .= ($self->{CCFLAGS} ? ' ' : '').'-Wno-error=implicit-function-declaration';
+
+    $self->SUPER::cflags(@_);
+}
+
 1;
